import unittest

from safeconfig import Array, Variable


class TestArrayMethods(unittest.TestCase):
    def setUp(self):
        self.array = Array(int, description="Test array", default=[1, 2, 3])

    def test_default_value(self):
        self.assertEqual(self.array.default, [1, 2, 3])

    def test_set_get_value(self):
        self.array.set([4, 5, 6])
        self.assertEqual(self.array.get(), [4, 5, 6])

    def test_invalid_value(self):
        with self.assertRaises(ValueError):
            self.array.set(["invalid"])

    def test_append_value(self):
        self.array.set([1, 2])
        self.array.append(3)
        self.assertEqual(self.array.get(), [1, 2, 3])


if __name__ == "__main__":
    unittest.main()



import argparse
import json
import os
import tempfile
import unittest
from unittest.mock import patch

import yaml

from safeconfig import CLIParser, Struct, Variable


class TestConfigStruct(Struct):
    field1 = Variable(int, description="An integer field")
    field2 = Variable(str, description="A string field")


class TestCLIParser(unittest.TestCase):
    def setUp(self):
        self.test_json_config = tempfile.NamedTemporaryFile(
            delete=False, suffix=".json", mode="w"
        )
        self.test_yaml_config = tempfile.NamedTemporaryFile(
            delete=False, suffix=".yaml", mode="w"
        )

        json.dump({"field1": 10, "field2": "test"}, self.test_json_config)
        yaml.dump({"field1": 20, "field2": "yaml_test"}, self.test_yaml_config)

        self.test_json_config.close()
        self.test_yaml_config.close()

    def tearDown(self):
        os.remove(self.test_json_config.name)
        os.remove(self.test_yaml_config.name)

    @patch("argparse.ArgumentParser.parse_args")
    def test_load_json_config(self, mock_parse_args):
        mock_parse_args.return_value = argparse.Namespace(
            config=self.test_json_config.name
        )

        cli_parser = CLIParser(TestConfigStruct())
        config = cli_parser.parse_args()

        self.assertEqual(config.field1.get(), 10)
        self.assertEqual(config.field2.get(), "test")

    @patch("argparse.ArgumentParser.parse_args")
    def test_load_yaml_config(self, mock_parse_args):
        mock_parse_args.return_value = argparse.Namespace(
            config=self.test_yaml_config.name
        )

        cli_parser = CLIParser(TestConfigStruct())
        config = cli_parser.parse_args()

        self.assertEqual(config.field1.get(), 20)
        self.assertEqual(config.field2.get(), "yaml_test")

    @patch("argparse.ArgumentParser.parse_args")
    def test_override_config(self, mock_parse_args):
        mock_parse_args.return_value = argparse.Namespace(
            config=self.test_json_config.name, field1=30, field2="override"
        )

        cli_parser = CLIParser(TestConfigStruct())
        config = cli_parser.parse_args()

        self.assertEqual(config.field1.get(), 30)
        self.assertEqual(config.field2.get(), "override")


if __name__ == "__main__":
    unittest.main()



import unittest

from safeconfig import Variable


class TestVariableMethods(unittest.TestCase):
    def setUp(self):
        self.variable = Variable(int, description="Test variable", default=5)

    def test_default_value(self):
        self.assertEqual(self.variable.default, 5)

    def test_set_get_value(self):
        self.variable.set(15)
        self.assertEqual(self.variable.get(), 15)

    def test_invalid_type(self):
        with self.assertRaises(ValueError):
            self.variable.set("invalid")


if __name__ == "__main__":
    unittest.main()
